function f=mukubogau(p,data)
% F=MUKUBOGAU(P,DATA)
%
% Sept 09  This becomes the switchyard also for Dynamical KT in
% zero field.
% parameters:
% p(1) = Amp
% p(2) = Gau, longitudinal field (Gauss)
% p(3) = DeGa, static width (mus-1)
% p(4) = DeLo, independent muon 1/T1 (mus-1)
% p(5) = Nu, scattering frequency for Dynamical KT (mus-1)
%
% If p(5) ~= 0 must be p(2)=p(4)=0 (this is checked in MUFIT_GUI) 
% If p(2) ~= 0 The static part is a modification of MUKUBOGAUSS: 
% For zero field uses analytical formula 
%          p(1)/3*(1+2*(1-(p(3)*t).^2).*exp(-(p(3)*t).^2 /2);
% For finite fields integral of kernel given in 
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.KuboFunctions
% calculating static Kubo-Toyabe relaxation with external
% longitudinal field (unlim) by cumsum, instead of too slow quad
% (MUKUBOGAUSS uses interpolation of calculation over few points)

  
global MU_TABLE

if p(5)==0
    if p(3)==0
        f=p(1)*ones(size(data(1,:))); % no relaxation
    else
        if abs(p(2)/p(3))<2.5e-7, % consider zero field 
            Dtt=(p(3)*data(1,:)).^2;
            f=p(1)/3*(1+2*(1-Dtt).*exp(-Dtt/2));
        else % calculate cumsum integral with kernel for Gauss KT        
            w0=2*pi*MU_TABLE.GAMU*abs(p(2));
            dt=data(1,2)-data(1,1); % time bin width
            w0t=w0*data(1,:); 
            dt2=((p(3)*data(1,:)).^2)/2;
            dt2e=dt2.*(dt2<745)+745*(dt2>745); % to avoid underflow of exp
            g=exp(-dt2e).*(dt2<745); % underflow of exp is set to zero 
            y=2*p(3)^2/w0*g.*...
              ((p(3)/w0)^2*(sin(w0t)-w0t.*cos(w0t))-sin(w0t)); %kernel
            f=p(1)*(cumsum(y*dt)+1); % simplified rectangular integral
        end
    end
    f=f.*exp(-data(1,:)*p(4));
else
    dt=data(1,2)-data(1,1); % time bin width
    N=length(data(1,:)); % number of data bins
    t0=data(1,1); % initial bin
    n0=ceil(t0/dt); % extra bins between t=0 and t0
    tt=dt*[0:N+n0 -N-n0+1:-1]; % time base including data(1,:), with
                               % negative times
    
    gg=1/3*(1 + 2*(1 - ...
                   (p(3)*tt).^2)...
            .*exp(-(p(3)*tt).^2/2)).*(tt>=0); % padded KT
                                              % zero for negative times 
    expnut=exp(-p(5)*tt); % exp(-nu*tt)
    expnut(find(isinf(expnut)))=0; % enforce zero padding also at
                                   % negative times where expnut is Inf
    ff=fft(gg.*expnut); % Laplace transform = Fourier transform of
                        % gg*exp(-nu*t)
    FF=ff./(1-(1-exp(-p(5)*dt))*ff);  % convolution via Laplace transform
    
    dkt = real(ifft(FF));  % Inverse Laplace = Inverse Fourier
    
    dkt=dkt/dkt(1); % function at integer bins
    f=p(1)*interp1(tt,dkt,data(1,:),'linear');
end
% look for updated numerical calculations also into wikis/MuSR/*.m

