function f=mumud(p,d)
% F = MUMUD(P,D)
% P = minuit parameters
% D = data TIME or [TIME; ASYMMETRY; ASYMERRORS]
% zero field asymmetry for polycrystalline MuD-like straight
% "molecules", with an axial quadrupolar coupling along the Mu-D
% line
% Calculations by Marcello Mazzani - 2010
    
    global MU_TABLE

A=p(1);                        % Asymmetry
wd=2*pi*MU_TABLE.GAMU*p(2);    % dipolar frequency from Dipolar Field 
                               % B_d=mu0 gaF gamu h/(4 pi r^3) (input in Gauss)
wq=2e-3*pi*p(3);    % SECULAR Quadrupolar Freq. (us-1)
                    % input p(3)=nuQ*(3cos^2beta-1)/4 (in kHz)
                    % nuQ=  3 e Q Vzz /2hS(2S-1) 
lalong=p(4);  % Lorentzian Relaxation. (input in us-1)
latrans=p(5); % Lorentzian Relaxation. (input in us-1)

w1=sqrt(6*wd^2+4*wd*wq+wq^2); % us-1
w2=(wq-6*wd+w1)/2;  % us-1 
w3=(wq-6*wd-w1)/2;  % us-1
A0=(5*wq^2+4*wd^2+20*wd*wq)*exp(-lalong*d(1,:))/w1^2; %long component 
A1=6*wd^2/w1^2; % transverse component
A2=2*(w1^2-wq*w1-2*wd*w1)/w1^2; % transverse component
A3=2*(w1^2+wq*w1+2*wd*w1)/w1^2; % transverse component

f=A/6*(A0+(A1*cos(w1*d(1,:))+A2*cos(w2*d(1,:))+A3*cos(w3*d(1,:)))...
       .*exp(-latrans*d(1,:)));