function muplotpar(varargin)
% MUPLOTPAR(varargin) 
%
% called by MUFIT_GUI to produce plots of parameters from fit
% results, either vs T (argin1=1) or vs B (argin1=2) 
    global MU_MODEL MU_PATH MU_FIG
    % MU_MODEL.COMPONENT(k).PARAMETER(j).PLOT contains the plot
    % panel (0 or absent means do not plot)
    
    % construct filename
    filename=[MU_PATH.LOG MU_MODEL.NAME '.*.'  mugrouptag ...
              '_' num2str(MU_MODEL.FLAG.LOGVERSION) '.fit'];
    list=ls(filename);      % one file per line (a column of filenames)
    if isunix 
        lf=findstr(list,char(10));
        kk=lf(1);
        lista=strvcat(list(1:kk-1));% to obtain the same output    
        for k=lf(2:end)
            lista=strvcat(lista,list(kk+1:k-1)); % same output
            kk=k;
        end
        list=lista;
    end
    
    runs=[];
    %disp(['ls yields ' num2str(size(list,1)) ' lines']) %RDR
    for k=1:size(list,1) %number of lines
                         %disp([num2str(k) '-th line: ' list(k,:)])
        kbegin=findstr(list(k,:),MU_MODEL.NAME); % beginning of filename
        kend=findstr(list(k,:),'fit')+2; % end of filename
        string=list(k,kbegin(end):kend(end)); 
        % in case also the path contains the strings MU_MODEL.NAME
        % and/or 'fit' (then kbegin, kend are arrays)
        kk=findstr(string,'.');
        %disp(['run: ' string(kk(1)+1:kk(2)-1) ])
        runs=[runs str2num(string(kk(1)+1:kk(2)-1))]; 
    end
    [nparmin plotpar]=muparminuit;
    T=[];
    B=[];
    pf=zeros(nparmin,0);
    epf=pf;
    for run=runs
        filename=[MU_PATH.LOG MU_MODEL.NAME '.' num2str(run) '.' ...
                  mugrouptag '_' num2str(MU_MODEL.FLAG.LOGVERSION) '.fit'];
        load(filename,'-mat')
        T=[T str2num(MU_MODEL_F.TEMPERATURE(1:end-1))];
        B=[B str2num(MU_MODEL_F.FIELD(1:end-1))];
        pf=[pf MU_MODEL_F.PAR'];
        epf=[epf MU_MODEL_F.EPAR'];
    end
    
    sample=[MU_MODEL_F.SAMPLE MU_MODEL_F.ORIENTATION];
    flag=cell2mat(varargin(1));
    switch flag
      case 1
        % plot vs T
        x=T;
        labelx='T (K)';
        % panel 1
      case 2
        % plot vs B
        x=B;
        labelx='B (G)';
      case 3
        % plot vs x (user defined)
        labelx='x';
        nruns=size(runs,2);
        if isfield(MU_FIG,'X')
           x=MU_FIG.X;
        else
            disp('TO PLOT vs x YOU MUST FIRST DEFINE X')
            disp('First declare:')
            disp('  global MU_FIG')
            disp(['Then define the ' num2str(nruns) ' values, e.g.'])
            disp(['  MU_FIG.X=[1:' num2str(nruns) '];'])
            disp(' [0 5 10 NaN 20] if you want to omit the 4th value]')
            return
        end
        nx=size(x,2);
        if nx~=nruns 
            disp(['Check! There are ' num2str(length(nruns)) ...
                  ' fits to plot. MU_FIG.X has ' num2str(nx) ...
                                ' values'])
            disp(['Fitted runs are: ' num2str(runs)])
            disp('(MU_FIG.X is part of global MU_FIG)')
            disp(' [0 5 10 NaN 20] if you want to omit the 4th value]')
            return
        end
      case 4
         % plot vs # (run number)
        labelx='Run number';
        x=runs;
    end
    % create of bring focus to figure
    figure(MU_FIG.PAR);
    set(MU_FIG.PAR,'Name',MU_FIG.PARNAME,'Visible','off');
    clf
    %how many panels?
    panels=max(plotpar);
    for k=1:panels
        if isempty(find(plotpar==k))
            disp(['WARNING! You have selected ' num2str(panels) ...
                ' panels, but no parameters in panel ' num2str(k)])
            disp(['Please use panel ' num2str(k) ' first'])
            return
        end
    end
    one=find(plotpar==1);
    two=find(plotpar==2);
    three=find(plotpar==3);
    four=find(plotpar==4);
    color=colormap(lines); %[0.8 0.2 0.2 ;0.6 0.2 0.4; 0.4 0.2 0.6;0.2 0.2 0.8]
    s={'o','s','^','d','p','v','>','>','h'};
    switch panels
      case 1
        siz=8;
        % one panel
        hold on
        yax=mucomp(one(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='Error in muplotpar'
        end
        l=length(one);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=one
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        xlabel(labelx)
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        axis(pos);
        set(gca,'Box','on')
        text(0.05*pos(2),1.05*pos(4),sample)
        hold off
      case 2
        % two panels
        siz=5;
        Xmin=0.20;
        Xmax=0.80;
        Xwidth=Xmax-Xmin;
        Ymin=0.1;
        Ymax=0.9;
        Ywidth=Ymax-Ymin;
        % Bottom panel; plotpar=2
        hbottom=axes('Position',[Xmin Ymin Xwidth Ywidth/2],'Box', ...
                            'on');
        hold on
        yax=mucomp(two(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(two);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=two
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        xlabel(labelx)
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        axis(pos);
        hold off
        
        % Top panel plotpar=1
        htop=axes('Position',[Xmin Ymin+Ywidth/2 Xwidth Ywidth/2],...
                  'Box','on',...
                  'Xticklabel',[]);
                hold on
        yax=mucomp(one(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(one);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=one
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        axis(pos);
        text(0.05*pos(2),1.05*pos(4),sample)
        hold off

      case 3
        % three panels
        siz=6;
        Xmin=0.25;
        Xmax=0.75;
        Xwidth=Xmax-Xmin;
        Ymin=0.09;
        Ymax=0.91;
        Ywidth=Ymax-Ymin;
        % Bottom panel; plotpar=3
        hbottom=axes('Position',[Xmin Ymin Xwidth Ywidth/3],'Box', ...
                            'on');
        hold on
        yax=mucomp(three(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(three);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=three
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        xlabel(labelx)
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        pos(4)=0.99999*pos(4); % to avoid overlapping labels
        axis(pos);
        hold off
        % Middle panel plotpar=2
        hmiddle=axes('Position',...
                     [Xmin Ymin+Ywidth/3 Xwidth Ywidth/3],...
                     'Box','on',...
                     'Xticklabel',[]);
                hold on
        yax=mucomp(two(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(two);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=two
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;        
        pos(4)=0.99999*pos(4); % to avoid overlapping labels
        axis(pos);
        hold off
        % Top panel: plotpar=1
        htop=axes('Position',...
                  [Xmin Ymin+2*Ywidth/3 Xwidth Ywidth/3],...
                  'Box','on',...
                  'Xticklabel',[]);
                hold on
        yax=mucomp(one(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(one);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=one
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        axis(pos);
        text(0.05*pos(2),1.05*pos(4),sample)
        hold off
      case 4
        % four panels
        siz=6;
        Xmin=0.1;
        Xmax=0.9;
        Xwidth=Xmax-Xmin;
        Ymin=0.09;
        Ymax=0.91;
        Ywidth=Ymax-Ymin;
        % Top left panel; plotpar=1
        htopleft=axes('Position',...
                      [Xmin Ymin+Ywidth/2 Xwidth/2 Ywidth/2],...
                      'Box','on',...
                      'Xticklabel',[]);
        hold on
        yax=mucomp(one(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(one);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=one
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
            pos(2)=0.99999*pos(2);
        else
            pos(1)=pos(1)-0.99;
            pos(2) = pos(2)+0.99;
        end
        pos(3)=minpf;
        axis(pos);
        text(0.5*pos(2),1.05*pos(4),sample)
        hold off
        % Bottom left panel plotpar=2
        hbotleft=axes('Position',[Xmin Ymin Xwidth/2 Ywidth/2],...
                      'Box','on');
        hold on
        yax=mucomp(two(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(two);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=two
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
             errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        xlabel(labelx)
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
            pos(2)=0.99999*pos(2);
        else
            pos(1)=min(runs)-0.99;
            pos(2)=max(runs)+0.99;
        end
        pos(3)=minpf;
        pos(4)=0.99999*pos(4); % to avoid overlapping labels
        axis(pos);
        hold off
        % Top right panel: plotpar=3
        htopright=axes('Position',...
                       [Xmin+Xwidth/2 Ymin+Ywidth/2 Xwidth/2 Ywidth/2],...
                       'Box','on',...
                       'Xticklabel',[],...
                       'YAxisLocation','Right');
        hold on
        yax=mucomp(three(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(three);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=three
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        axis(pos);
        hold off
        % Bottom right panel: plotpar=3
        hbotright=axes('Position',...
                       [Xmin+Xwidth/2 Ymin Xwidth/2 Ywidth/2],...
                       'Box','on',...
                       'YAxisLocation','Right');
        hold on
        yax=mucomp(four(1));
        switch upper(yax(3:5))
          case 'AMP'
            labely='Amplitude';
          case {'DEL' 'DEG' 'DEC'}
            labely='Decay ({\mu}s^{-1})';
          case 'GAU'
            labely='Field (G)';
          case 'PHI'
            labely='Phase (deg)';
          case 'BET'
            labely='\beta';
          case 'LPH'
            labely='d\alpha';
          otherwise
            labely='muplotpar line 60-75'
        end
        l=length(four);
        leg=cell(1,l);
        l=0;
        minpf=0;
        for k=four
            l=l+1;
            [n c p]=mucomp(k);
            j=mugui2minuit(k);
            minpf=min([minpf pf(j,:)]);
            errorbar(x,pf(j,:),epf(j,:),char(s(c)),'markersize',siz,...
                     'markerfacecolor',color(c,:),'markeredgecolor', ...
                     color(c,:));
            leg(l)={n}; % name
        end
        xlabel(labelx)
        ylabel(labely)
        legend(leg)
        pos=axis;
        if flag~=4, 
            pos(1)=0; 
        else
            pos(1)=min(runs)-1;
            pos(2)=max(runs)+1;
        end
        pos(3)=minpf;
        pos(4)=0.99999*pos(4); % to avoid overlapping labels
        axis(pos);
        hold off
    end
    set(MU_FIG.PAR,'Visible','on');
