function muprofcn
global MU_MODEL

    %
    % recalculates array MU_MODEL.COMPONENT(k).SHARE to redistribute parameters  
    % and MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT for linear relations
    % 
    % array share must have as many elements as the total number of parameters
    % in Fit Parameter Menu
    % and share(j) is the index of par inside fminuit 
    % where parameters with FLAG += do not appear

    shareglobal=[]; % from scratch at the beginning; it contains
                    % all indices
    par=0;
    % FIRST PASSAGE: ~!=, + are just counted in
    for k=1:MU_MODEL.COMPONENTNUMBER
        share=[]; % this is the component SHARE array for the
                  % present component; it contains only indices for
                  % the present component 
        for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
            switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
              case {'~','!'} % also a regular fminuit parameter
                par=par+1; % index is incremented only for ~! parameters
                share=[share par]; % for present component
                shareglobal=[shareglobal par]; % total
                MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                    ['p(' num2str(par) ')']; % new 1.05 version
              case '+' % linear relation must be reassigned and
                       % stored in 
                       % MU_MODEL.COMPONENT(k).PARAMETER(kp).MENU2MINUIT
                         % at a later passage (since reference
                         % could be to a subsequent parameter,
                         % shareglobal must be completed)
                share=[share 0]; % for present component
                shareglobal=[shareglobal 0]; % total
              case '=' % must be a preceding parameter
                parshared=MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE;
                share=[share shareglobal(parshared)]; % for present component
                shareglobal=[shareglobal shareglobal(parshared)]; % total
                MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                    ['p(' num2str(shareglobal(parshared)) ')']; 
                % new 1.05 version
            end
        end
        %       disp (['comp=' num2str(k) ': ' num2str(share)])
        MU_MODEL.COMPONENT(k).SHARE=share; % remains in 1.05
    end
    % SECOND PASSAGE: recalculate +
    for k=1:MU_MODEL.COMPONENTNUMBER
         for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
            switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
                case '+' % linear relation must be reassigned and
                         % stored in 
                         % MU_MODEL.COMPONENT(k).PARAMETER(kp).MENU2MINUIT
                  [OK open close par]=muparse(...
                      MU_MODEL.COMPONENT(k).PARAMETER(j).LINREL);
                  % get open = indices of 'p('
                  %     close = indices of ')'
                  %     par = indices of SOURCE parameters
                  %           in Menu (shareglobal) list
                  string=MU_MODEL.COMPONENT(k).PARAMETER(j).LINREL;
                  % this is the original relation, already verified
                  % by muparse when it was typed in
                  % It will be rewritten in string
                  for l=1:length(open)
                      % first make space
                      if close(l)-open(l)==3 % only one digit per index
                          string(open(l)+2:end+1)=['  ' ...
                                              string(close(l):end)];

                          close(l)=close(l)+1; % shift forward
                          for ll=l+1:length(open) % shift forward
                                                  % all the following
                              open(ll)=open(ll)+1;
                              close(ll)=close(ll)+1;
                          end
                          % make room for two (blank) digits and
                          % copy rest                          
                      else % already two digits per index
                         string(open(l)+2:close(l)-1)='  '; % blank them 
                      end 
                      % then write reallocated index
                      nback=2; % index is one digit
                      if fix(shareglobal(par(l))/10) 
                          nback=1; % index is two digits
                      end
                      string(open(l)+2:close(l)-nback)=...
                          num2str(shareglobal(par(l)));
                      % write the fminuit index
                      % between p(_  and _) or __), depending on
                      % number of digits 
                  end
                  % finaly store in MENU2MINUIT
                  MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                      string; % new 1.05 version
            end
        end
    end

